@@ -580,6 +580,19 @@
 						$this->_oChild->eventHandler($iEvent_);
 						$this->_oChild->resetOldExpr();
 					}
+
+					/*
+						Uncomment the next two lines of code if you want
+						the DOCUMENT FOOTER being printed AFTER the PAGE FOOTER
+						I think it becomes a little weird when you have for example
+						"page number 10" and then "GRAND TOTAL" there, but it's a kind of
+						taste.
+						To make this a little more beauty we'll need another layer of detail,
+						for example, PAGE NUMBER_FOOTER. But that's another history. :-)
+							
+					if($this->getName()=="DOCUMENT LAYER")
+						$oPage->printFooter();
+					*/
 					$this->printFooter();
 					$this->reset();
 					$this->_bHeader=true;
