@@ -41,6 +41,7 @@
 		var $_aEnv;				// enviroment vars
 		var $_sClassName;		// report class name to create
 		var $_sTmp;				// temporary dir
+		var $_oCon;				// database connection handle
 
 		/***************************************************************************
 		*																									*
@@ -155,8 +156,13 @@
 				require_once($sOut);	
 			}	
 
-			// run the generated class	
+			// include the generated class	
 			$oReport = new $this->_sClassName;
+			
+			// set the database connection handle, if there is one
+			$oReport->setDatabaseConnection($this->_oCon);
+
+			// run the generated class
 			$this->_sXMLOutputFile = $oReport->run($this->_sXMLOutputFile,$this->_aEnv);
 
 			// check if the XML file exists, we need data!
@@ -601,5 +607,14 @@
 		function getClassName(){
 			return is_null($this->_sClassName)?"PHPReport":$this->_sClassName;
 		}
+
+		/******************************************************************************
+		*																										*
+		*	Set the database connection handle														*
+		*																										*
+		******************************************************************************/
+		function setDatabaseConnection(&$_oCon){
+			$this->_oCon =& $_oCon;
+		}		
 	}
 ?>
