@@ -18,7 +18,7 @@
 
 	function db_columnName($oStmt,$iPos) {
 		$aFieldInfo = ibase_field_info($oStmt,$iPos-1);
-		return $aFieldInfo["name"];
+		return $aFieldInfo["alias"];
 	}
 	
 	function db_columnType($oStmt,$iPos) {
